@@ -1,9 +1,7 @@
 from rtgo._mythreads import *
-import numpy
 import multiprocessing
 from logging import Logger
-
-
+import math
 LOGGER = Logger("JobHandler Logger")
 
 
@@ -91,7 +89,7 @@ def go(func, args, arg_data_index, n_threads=0):
         n_threads = data_count
 
     # split data by number of threads (works with DataFrames)
-    data = [x.tolist() for x in numpy.array_split(args[arg_data_index], n_threads)]
+    data = __split_list(args[arg_data_index], n_threads, data_count)
 
     # spool up new threads
     for i in range(n_threads):
@@ -109,3 +107,34 @@ def go(func, args, arg_data_index, n_threads=0):
         thread.start()
 
     return __get_results_from_threads(running_threads)
+
+
+def __split_list(input_list, n_threads, data_count):
+    """
+    Splits a list into n lists based on n_threads value.
+    :param input_list: List to be split.
+    :param n_threads: Number of threads to split the data into.
+    :param data_count: Total number of items in input_list
+    :return: List containing a list for each thread
+    """
+    if type(input_list) == list:
+        remainder = data_count % n_threads
+        new_list = []
+        # split data records into one list per thread
+        for i in range(n_threads):
+            lower_slice = math.floor(i * (data_count / n_threads))
+            upper_slice = math.floor((i + 1) * (data_count / n_threads))
+            if (i + 1) == n_threads:
+                new_list.append(input_list[lower_slice:upper_slice])
+            else:
+                new_list.append(input_list[lower_slice:upper_slice])
+        # spread remainder records across sub lists
+        while remainder > 0:
+            for i in range(n_threads):
+                if remainder:
+                    current_record = input_list[(data_count - (remainder - 1))]
+                    new_list[i].append(current_record)
+                    remainder = remainder - 1
+                else:
+                    break
+        return new_list
